import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { BaseDeviceCategoryVO, BaseDeviceCategoryForm, BaseDeviceCategoryQuery } from '@/api/dms/baseDeviceCategory/types';

/**
 * 查询设备大类信息列表
 * @param query
 * @returns {*}
 */

export const listBaseDeviceCategoryInWMS = (query?: BaseDeviceCategoryQuery): AxiosPromise<BaseDeviceCategoryVO[]> => {
  return request({
    url: '/dms/baseDeviceCategory/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询设备大类信息详细
 * @param deviceCategoryId
 */
export const getBaseDeviceCategoryInWMS = (deviceCategoryId: string | number): AxiosPromise<BaseDeviceCategoryVO> => {
  return request({
    url: '/dms/baseDeviceCategory/' + deviceCategoryId,
    method: 'get'
  });
};

/**
 * 新增设备大类信息
 * @param data
 */
export const addBaseDeviceCategoryInWMS = (data: BaseDeviceCategoryForm) => {
  return request({
    url: '/dms/baseDeviceCategory',
    method: 'post',
    data: data
  });
};

/**
 * 修改设备大类信息
 * @param data
 */
export const updateBaseDeviceCategoryInWMS = (data: BaseDeviceCategoryForm) => {
  return request({
    url: '/dms/baseDeviceCategory',
    method: 'put',
    data: data
  });
};

/**
 * 删除设备大类信息
 * @param deviceCategoryId
 */
export const delBaseDeviceCategoryInWMS = (deviceCategoryId: string | number | Array<string | number>) => {
  return request({
    url: '/dms/baseDeviceCategory/' + deviceCategoryId,
    method: 'delete'
  });
};


/**
 * 下拉框查询设备大类信息列表
 * @param query
 * @returns {*}
 */
export function getBaseDeviceCategoryListInWMS (query) {
    return request({
        url: '/dms/baseDeviceCategory/getBaseDeviceCategoryList',
        method: 'get',
        params: query
    });
};
